This is an internal function to sim_trajectory_R. It does the
actual sampling once all of the functions have been checked and setup.
sim_trajectory_base_R_decoupled_SIS(
x0,
h0,
SPN_P,
theta,
times,
num_reps,
stepFun,
events = NULL,
batch = NULL,
Sout = NULL,
verbose = TRUE,
cube = NULL
)matrix of sampled values
the initial marking of the SPN (initial state)
initial human state distribution
stochastic petri net, places
parameters
sequence of sampling times
number of repetitions to run
a sampling function
a data.frame of events (uses the same format as required in package deSolve for consistency, see events for more information)
a list of batch migration events, created from batch_migration, may be set to NULL if not used
an optional matrix to track event firings
print a progress bar?
inheritance cube