The params argument supplies all of the ecological parameters necessary
to calculate equilibrium values. This function requires the nE,
nL, nP, and nEIP parameters to be specified. For more details, see
equilibrium_SEI_SIS
spn_P_epi_decoupled_node(params, cube)a list with two elements: ix contains labeled indices of the places
by life stage, u is the character vector of places (P)
a named list of parameters (see details)
an inheritance cube from the MGDrivE package (e.g. cubeMendelian)
For examples of using this function, see:
vignette("epi-node", package = "MGDrivE2")