This function makes the set of transitions (T) for a SPN. It is used alone if
our model is a single-node metapopulation of mosquito; otherwise
it is used as part of other functions to make SPN models with larger state
spaces (metapopulation models, see spn_T_epiSIS_network).
spn_T_epi_decoupled_node(spn_P, params, cube)a list with two elements: T contains transitions packets as lists,
v is the character vector of transitions (T)
set of places produced by spn_P_epiSIS_node_decoupled function
a named list of parameters (see details)
an inheritance cube from the MGDrivE package (e.g. cubeMendelian)
This function takes the places produced from spn_P_epiSIS_node_decoupled
and builds all possible transitions between subsets of those places.
The params argument supplies all of the ecological parameters necessary
to calculate equilibrium values. This function requires the nE,
nL, nP, and nEIP parameters to be specified. For more details, see
equilibrium_SEI_SIS
While this function produces all structural information related to transitions,
hazards are produced by a separate function, spn_hazards.
This is used by both decoupled SIS and Imperial transmission model sampling.
For examples of using this function, see:
vignette("epi-node-decoupled", package = "MGDrivE2")